Basic
=====

Learn how to write a general MLO program and the basic features of Betty. We will use
**Data Reweighting for Long-Tailed Image Classification** as our running example
throughout this tutorial.

Basic 1: :doc:`How to write an MLO program (Quick Start) <basic_start>`

Basic 2: :doc:`Add validation for an MLO program <basic_validation>`

Basic 3: :doc:`Enable logging <basic_logging>`

Basic 4: :doc:`Reduce GPU memory footprint <basic_memory>`

.. toctree::
   :maxdepth: 1
   :hidden:

   Quick Start<basic_start.rst>
   Add Validation<basic_validation.rst>
   Add Logging<basic_logging.rst>
   Memory Optimization<basic_memory.rst>
